@@ -41,6 +41,7 @@ EXTENSIONS = {
     'cxx': {'text', 'c++'},
     'cylc': {'text', 'cylc'},
     'dart': {'text', 'dart'},
+    'dbc': {'text', 'dbc'},
     'def': {'text', 'def'},
     'dll': {'binary'},
     'dtd': {'text', 'dtd'},
@@ -120,19 +121,24 @@ EXTENSIONS = {
     'lean': {'text', 'lean'},
     'lektorproject': {'text', 'ini', 'lektorproject'},
     'less': {'text', 'less'},
+    'lfm': {'text', 'lazarus', 'lazarus-form'},
     'lhs': {'text', 'literate-haskell'},
     'libsonnet': {'text', 'jsonnet'},
     'lidr': {'text', 'idris'},
     'liquid': {'text', 'liquid'},
+    'lpi': {'text', 'lazarus', 'xml'},
+    'lpr': {'text', 'lazarus', 'pascal'},
     'lr': {'text', 'lektor'},
     'lua': {'text', 'lua'},
     'm': {'text', 'objective-c'},
+    'm4': {'text', 'm4'},
     'make': {'text', 'makefile'},
     'manifest': {'text', 'manifest'},
     'map': {'text', 'map'},
     'markdown': {'text', 'markdown'},
     'md': {'text', 'markdown'},
     'mdx': {'text', 'mdx'},
+    'meson': {'text', 'meson'},
     'mib': {'text', 'mib'},
     'mjs': {'text', 'javascript'},
     'mk': {'text', 'makefile'},
@@ -142,6 +148,7 @@ EXTENSIONS = {
     'modulemap': {'text', 'modulemap'},
     'mscx': {'text', 'xml', 'musescore'},
     'mscz': {'binary', 'zip', 'musescore'},
+    'mustache': {'text', 'mustache'},
     'myst': {'text', 'myst'},
     'ngdoc': {'text', 'ngdoc'},
     'nim': {'text', 'nim'},
@@ -151,6 +158,7 @@ EXTENSIONS = {
     'njk': {'text', 'nunjucks'},
     'otf': {'binary', 'otf'},
     'p12': {'binary', 'p12'},
+    'pas': {'text', 'pascal'},
     'patch': {'text', 'diff'},
     'pdf': {'binary', 'pdf'},
     'pem': {'text', 'pem'},
@@ -327,6 +335,8 @@ NAMES = {
     'LICENSE': EXTENSIONS['txt'],
     'MAINTAINERS': EXTENSIONS['txt'],
     'Makefile': EXTENSIONS['mk'],
+    'meson.build': EXTENSIONS['meson'],
+    'meson_options.txt': EXTENSIONS['meson'],
     'makefile': EXTENSIONS['mk'],
     'NEWS': EXTENSIONS['txt'],
     'NOTICE': EXTENSIONS['txt'],
